# Generated by Django 3.1.5 on 2021-01-11 13:32

import ckeditor.fields
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0006_orderform_access_code'),
    ]

    operations = [
        migrations.AddField(
            model_name='orderform',
            name='closed',
            field=models.BooleanField(default=False, verbose_name='Form closed for orders'),
        ),
    ]
