# Generated by Django 3.1.3 on 2020-12-18 10:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0002_auto_20201215_2136'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='order',
            name='in_progress',
        ),
        migrations.AddField(
            model_name='order',
            name='submitted',
            field=models.BooleanField(default=False, verbose_name='Submitted'),
        ),
    ]
