{% load i18n %}
<form action="" method="post" name="single-action">
  {% csrf_token %}
  <input type="hidden" name="single-action-pk" value="{{ pk }}">
  <a class="btn-flat green-text waves-effect waves-green" title="{% trans "Show details" %}"
     href="{% url "show_order" pk %}">
    <i class="material-icons center iconify" data-icon="mdi:file-find"></i>
  </a>
  <a class="btn-flat orange-text waves-effect waves-orange" title="{% trans "Show details" %}"
     href="{% url "show_order" pk %}">
    <i class="material-icons center iconify" data-icon="mdi:pencil-outline"></i>
  </a>
  <button type="submit" class="btn-flat primary-color-text waves-effect waves-green" title="{% trans "Mark as paid" %}"
          value="yes"
          name="mark-as-paid">
    <i class="material-icons center iconify" data-icon="mdi:currency-eur"></i>
  </button>
  <button type="submit" class="btn-flat primary-color-text waves-effect waves-green"
          title="{% trans "Mark as paid and send pay confirmation" %}" name="mark-as-paid-email" value="yes">
    <i class="material-icons center iconify" data-icon="mdi:currency-eur"></i>
    <i class="material-icons center iconify" data-icon="mdi:plus"></i><i
      class="material-icons center iconify" data-icon="mdi:email-outline"></i>
  </button>
  <button type="submit" class="btn-flat primary-color-text waves-effect waves-green" title="{% trans "Mark as sent" %}"
          value="yes"
          name="mark-as-sent">
    <i class="material-icons center iconify" data-icon="mdi:truck"></i>
  </button>
</form>