{% extends 'core/base.html' %}
{% load i18n material_form %}

{% block page_title %}
  {% trans "Edit order" %}
{% endblock %}
{% block browser_title %}
  {% trans "Edit order" %}
{% endblock %}

{% block content %}
  <form action="" method="post">
    {% csrf_token %}
    {% form form=form %}{% endform %}
    {% include "core/partials/save_button.html" %}
  </form>
{% endblock %}
